==> haskell-quickcheck-unicode-1.0.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-unicode
version: 1.0.1.0
id: quickcheck-unicode-1.0.1.0-HEP9oVmW6DsEFOTsikkyn1
key: quickcheck-unicode-1.0.1.0-HEP9oVmW6DsEFOTsikkyn1
license: BSD2
copyright: 2014-2017 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/quickcheck-unicode
synopsis: Generator and shrink functions for testing
          Unicode-related software.
description:
    Generator and shrink functions for testing
    Unicode-related software.
category: Testing, Text
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.Unicode
abi: 1d0c941360d1821388da854148ba9806
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/quickcheck-unicode-1.0.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/quickcheck-unicode-1.0.1.0
hs-libraries: HSquickcheck-unicode-1.0.1.0-HEP9oVmW6DsEFOTsikkyn1
depends:
    base-4.10.1.0 QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=a871331a7e5e7b5c37818b7997512ddd
haddock-interfaces: /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-unicode
version: 1.0.1.0
id: quickcheck-unicode-1.0.1.0-4AEKC3HtY3N76OKcPLG4Xj
key: quickcheck-unicode-1.0.1.0-4AEKC3HtY3N76OKcPLG4Xj
license: BSD2
copyright: 2014-2017 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/quickcheck-unicode
synopsis: Generator and shrink functions for testing
          Unicode-related software.
description:
    Generator and shrink functions for testing
    Unicode-related software.
category: Testing, Text
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.Unicode
abi: 716b0a176ffbc22dfc77088b1344edd8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/quickcheck-unicode-1.0.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/quickcheck-unicode-1.0.1.0
hs-libraries: HSquickcheck-unicode-1.0.1.0-4AEKC3HtY3N76OKcPLG4Xj
depends:
    base-4.10.1.0 QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
haddock-interfaces: /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
